@@ -13,13 +13,23 @@ class DataFrameGroupBy:
         results = itertools.chain.from_iterable(results)
         keys, values, mutated = zip(*results)
         mutated = any(mutated)
+        
+        # GH #150
+        pd_version = tuple(map(int, pd.__version__.split('.')[:2]))
+        if pd_version < (1, 3):
+            args = keys, values
+        elif pd_version < (1, 4):
+            args = df_grouped._selected_obj, keys, values
+        else:
+            args = df_grouped._selected_obj, values
+            
         return df_grouped._wrap_applied_output(
-            keys, values, not_indexed_same=df_grouped.mutated or mutated
+            *args, not_indexed_same = df_grouped.mutated or mutated
         )
 
     @staticmethod
     def get_chunks(nb_workers, df_grouped, *args, **kwargs):
-        chunks = chunk(len(df_grouped), nb_workers)
+        chunks = chunk(df_grouped.ngroups, nb_workers)
         iterator = iter(df_grouped)
 
         for chunk_ in chunks:
