@@ -1,8 +1,4 @@
-import itertools
-from datetime import timedelta
-
 import pandas as pd
-from pandas.tseries.frequencies import to_offset
 
 from pandarallel.utils.tools import chunk, PROGRESSION
 
@@ -14,8 +10,21 @@ class ExpandingGroupBy:
 
     @staticmethod
     def get_chunks(nb_workers, expanding_groupby, *args, **kwargs):
-        chunks = chunk(len(expanding_groupby._groupby), nb_workers)
-        iterator = iter(expanding_groupby._groupby)
+        pandas_version = tuple((int(item) for item in pd.__version__.split(".")))
+
+        nb_items = (
+            expanding_groupby._grouper.ngroups
+            if pandas_version >= (1, 3)
+            else len(expanding_groupby._groupby)
+        )
+
+        chunks = chunk(nb_items, nb_workers)
+
+        iterator = (
+            expanding_groupby._grouper.get_iterator(expanding_groupby.obj)
+            if pandas_version > (1, 3)
+            else iter(expanding_groupby._groupby)
+        )
 
         for chunk_ in chunks:
             yield [next(iterator) for _ in range(chunk_.stop - chunk_.start)]
@@ -23,7 +32,8 @@ class ExpandingGroupBy:
     @staticmethod
     def att2value(expanding):
         attributes = {
-            attribute: getattr(expanding, attribute) for attribute in expanding._attributes
+            attribute: getattr(expanding, attribute)
+            for attribute in expanding._attributes
         }
 
         return attributes
@@ -35,6 +45,8 @@ class ExpandingGroupBy:
         # TODO: See if this pd.concat is avoidable
         results = []
 
+        attribute2value.pop("_grouper", None)
+
         for iteration, (name, df) in enumerate(tuples):
             item = df.expanding(**attribute2value).apply(func, *args, **kwargs)
             item.index = pd.MultiIndex.from_product([[name], item.index])
